@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2023
-;; Version: 2.0
+;; Version: 2.1
 ;; Package-Requires: ((emacs "28.1") (compat "30"))
 ;; URL: https://github.com/minad/jinx
 ;; Keywords: convenience, text
@@ -256,8 +256,10 @@ checking."
   "Menu used when Jinx is active."
   '("Jinx"
     ["Correct nearest" jinx-correct]
-    ["Correct all" (jinx-correct t)
+    ["Correct all" jinx-correct-all
      :keys "\\[universal-argument] \\[jinx-correct]"]
+    ["Correct word" jinx-correct-word
+     :keys "\\[universal-argument] \\[universal-argument] \\[jinx-correct]"]
     ["Change languages" jinx-languages]
     "----"
     ["Manual" (info "(jinx)")]
@@ -366,6 +368,7 @@ dictionaries.  Afterwards `jinx--syntax-overrides' are applied.")
 (put 'jinx-overlay 'insert-in-front-hooks (list #'jinx--overlay-modified))
 (put 'jinx-overlay 'insert-behind-hooks   (list #'jinx--overlay-modified))
 (put 'jinx-overlay 'keymap                'jinx-overlay-map)
+(put 'jinx-overlay 'help-echo             "Jinx: \\`mouse-3' menu, \\[jinx-correct] correct, \\`M-p' previous, \\`M-n' next")
 
 ;;;; Predicates
 
@@ -742,18 +745,22 @@ The word will be associated with GROUP and get a prefix key."
           (setq list (jinx--add-suggestion list ht w group)))))
     (dolist (w (jinx--session-suggestions word))
       (setq list (jinx--add-suggestion list ht w "Suggestions from session")))
-    (cl-loop for (key . fun) in jinx--save-keys
-             for actions = (funcall fun nil key word) do
-             (when (and actions (not (consp (car actions))))
-               (setq actions (list actions)))
-             (cl-loop for (k w a) in actions do
-                      (push (propertize
-                             (concat (propertize (if (stringp k) k (char-to-string k))
-                                                 'face 'jinx-save 'rear-nonsticky t)
-                                     w)
-                             'jinx--group "Accept and save"
-                             'jinx--suffix (format #(" [%s]" 0 5 (face jinx-annotation)) a))
-                            list)))
+    (cl-loop
+     for (key . fun) in jinx--save-keys
+     for actions = (funcall fun nil key word) do
+     (when (and actions (not (consp (car actions))))
+       (setq actions (list actions)))
+     (cl-loop
+      for (k w a) in actions
+      for k2 = (propertize (if (stringp k) k (char-to-string k))
+                           'face 'jinx-save 'rear-nonsticky t)
+      for a2 = (format #(" [%s]" 0 5 (face jinx-annotation)) a)
+      do (cl-loop
+          for w2 in (delete-consecutive-dups (list w (downcase w))) do
+          (push (propertize (concat k2 w2)
+                            'jinx--group "Accept and save"
+                            'jinx--suffix a2)
+                list))))
     (nreverse list)))
 
 (defun jinx--correct-affixation (cands)
@@ -855,7 +862,7 @@ Optionally show prompt INFO and insert INITIAL input."
                                     ,(overlay-start ov) ,(overlay-end ov)
                                     ,(concat (if (stringp k) k (char-to-string k)) w))]
                               menu)))
-      (easy-menu-create-menu (format "Correct `%s'" word)
+      (easy-menu-create-menu (format "Correct \"%s\"" word)
                              (delete-dups (nreverse menu))))))
 
 (defun jinx--load-dicts ()
@@ -1101,7 +1108,7 @@ This command dispatches to the following commands:
 ;;;###autoload
 (define-minor-mode jinx-mode
   "Enchanted Spell Checker."
-  :lighter (:eval (concat " Jinx[" jinx-languages "]"))
+  :lighter (" " (:eval (concat "Jinx[" jinx-languages "]")))
   :group 'jinx
   :keymap jinx-mode-map
   (cond
